;;;*                      DDSTEEL.LSP (Written By Kenny Ramage)
;;;*This is a merged file of all my Structural Steel Routines.
;;;*Version 1.2 Written March 1997.
;;;*This set of routines, draws Metric Structural Steel Sections.
;;;*Sections available are :-
;;;*            	Universal Beams
;;;*              Universal Columns
;;;*              Tapered Flange Channels
;;;*              Parallel Flange Channels
;;;*              Joists
;;;*              Equal Leg Channels
;;;*              Unequal Leg Channels
;;;*              Circular Hollow Sections (User Input Only)
;;;*              Rectangular/Square Hollow Sections (User Input Only)
;;;*All Section Properties are based on the South African Steel Construction
;;;*Handbook.
;;;*This programme was written by Kenny Ramage over a number of years, and is
;;;*constantly being updated & improved.
;;;*You are welcome to give to friends/colleagues, but please give me credit.
;;;*I can be contacted at the following :-
;;;*                 E-Mail ndbe51d1@db.za
;;;*                 Phone 092646332-2837
;;;*                       092646332-3737
;;;*                   Fax 092646332-3848
;;;*                  Post P.O. Box 1127
;;;*                       Oranjemund
;;;*                       NAMIBIA
;;;*                       9000
;;;*     Enjoy...........Bugs and all........
;;;*=========================================================================
;;;*NOTE!!!
;;;*Ddsteel.Dcl & Ddsteel.Dat must be in the Acad support path.
;;;*=========================================================================
;;;*Revisions
;;;*Grab routine added, programme updated to suit & error routine revised.
;;;*March 1997.
;;;*Routine updated  to suit R14 & Dialogue's streamlined.
;;;*March 1998.
;;;*=========================================================================
(prompt
  "\nSteel Sections Version 2.0 1998 \nby Kenny Ramage ndbe51d1@db.za"
)
(defun C:DDSTEEL (/ SIZA dcl_id)
  (initerr)
  (setq userclick1 T)
  (setvar "OSMODE" 0)
  (setvar "BLIPMODE" 0)
  (setvar "CMDECHO" 0)
  (setq SIZA "UBEAM")
  (setq dcl_id (load_dialog "ddsteel.dcl"))
  (if (not (new_dialog "ddsteel" dcl_id))
    (exit)
  )
  (setq w (dimx_tile "im")
	   h (dimy_tile "im"))
     (start_image "im")
     (fill_image 0 0 w h 5)
     (setq w1 (/ w 2))
     (setq h1 (/ h 2))
     (vector_image 0 h w1 0 2)
     (vector_image w1 0 w h 2)
     (vector_image 0 h w1 h1 2)
     (vector_image w1 h1 w h 2)
     (end_image)
  (action_tile
    "UB"
    "(setq SIZA \"UBEAM\")"
  )
  (action_tile
    "UC"
    "(setq SIZA \"UCOLUM\")"
  )
  (action_tile
    "JO"
    "(setq SIZA \"JOIST\")"
  )
  (action_tile
    "TFC"
    "(setq SIZA \"CHAN\")"
  )
  (action_tile
    "PFC"
    "(setq SIZA \"PCHAN\")"
  )
  (action_tile
    "ELA"
    "(setq SIZA \"RSA\")"
  )
  (action_tile
    "ULA"
    "(setq SIZA \"URSA\")"
  )
  (action_tile
    "RCR"
    "(setq SIZA \"SHOLL\")"
  )
  (action_tile
    "CCR"
    "(setq SIZA \"CHOLL\")"
  )
  (action_tile
    "cancel"
    "(done_dialog)(setq userclick nil)"
  )
  (action_tile
    "accept"
    "(done_dialog) (setq userclick T)"
  )
  (start_dialog)
  (unload_dialog dcl_id)
  (if userclick
    (progn
      (if (eq SIZA "UBEAM")
	(UBEAM)
      )
      (if (eq SIZA "UCOLUM")
	(UCOLUM)
      )
      (if (eq SIZA "JOIST")
	(JOIST)
      )
      (if (eq SIZA "CHAN")
	(CHAN)
      )
      (if (eq SIZA "CHOLL")
	(CHOLL)
      )
      (if (eq SIZA "RSA")
	(RSA)
      )
      (if (eq SIZA "URSA")
	(URSA)
      )
      (if (eq SIZA "SHOLL")
	(SHOLL)
      )
      (if (eq SIZA "PCHAN")
	(PCHAN)
      )
    )					;progn
  )					;if
  (reset)
  (if (= userclick1 nil)
    (c:ddsteel)
  );  
  (princ)
)					;defun
					;*
;;;*===================================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS UNIVERSAL BEAMS  
;;;*Written by K. Ramage September 1994.
;;;*DIALOGUE BOX ADDED AND REVISED FOR WINDOWS FUNCTIONALITY Aug. 1995
;;;*Merged with DDSTEEL.LSP March 1997
;;;*--------------------------------------------------------
(defun UBEAM (/	    SIZA	  size	file  fp    item  data	maxs  count
	      chrct numb  dlist	X     Y	    Z	  IP	P1    P2
	      P3    P4	  P5	P6    P7    P8	  P9	P10   P11
	      P12   P13	  P14	P15   P16   P17	  P18	P19   P20
	      P21   NAMES
	     )
;;;*---------------------------------------------------------
;;;*CONVERT TO RADIANS
  (setq	X (* pi (/ 90.0 180.0))
	Y pi
	Z (* pi (/ 270.0 180.0))
  )					;setq
;;;*----------------------------------------------------------
;;;*INITIALISE
  (setvar "CMDECHO" 0)
  (setvar "BLIPMODE" 0)
  (setq	NAMES '("100x55x8"	   "120x64x10"
		"140x73x13"	   "160x82x16"
		"180x91x19"	   "200x100x22"
		"203x133x25"	   "203x133x30"
		"254x146x31"	   "254x146x37"
		"254x146x43"	   "305x102x25"
		"305x102x29"	   "305x102x33"
		"305x165x41"	   "305x165x46"
		"305x165x54"	   "356x171x45"
		"356x171x51"	   "356x171x57"
		"356x171x67"	   "406x140x39"
		"406x140x46"	   "406x178x54"
		"406x178x60"	   "406x178x67"
		"406x178x75"	   "457x191x67"
		"457x191x75"	   "457x191x82"
		"457x191x90"	   "457x191x98"
		"533x210x82"	   "533x210x93"
		"533x210x101"	   "533x210x109"
		"533x210x122"	   "610x229x101"
		"610x229x113"	   "610x229x125"
		"610x229x140"	   "610x305x149"
		"610x305x179"	   "610x305x238"
		"686x254x125"	   "686x254x140"
		"686x254x152"	   "686x254x170"
	       )
  )
  (setq dcl_id (load_dialog "ddsteel.dcl"))
  (if (not (new_dialog "ubeam" dcl_id))
    (exit)
  )
  (start_list "selections")
  (mapcar 'add_list NAMES)
  (end_list)
  (action_tile
    "cancel"
    "(done_dialog) (setq userclick1 nil)"
  )
  (action_tile
    "accept"
    (strcat
      "(progn (setq SIZA (atof (get_tile \"selections\")))"
      "(done_dialog) (setq userclick1 T))"
    )
  )
  (start_dialog)
  (unload_dialog dcl_id)
  (if userclick1
    (progn
      (setq SIZA (fix SIZA))
      (setq SIZA (nth SIZA NAMES))
      (grab)
;;;*THIS ROUTINE DRAWS A UNIVERSAL BEAM.
      (mapcar 'set '(H B T1 T2 R1) dlist)
      (setvar "OSMODE" OLDSNAP)
      (while
      (setq IP (getpoint "\nInsertion Point: "))
      (setvar "OSMODE" 0)
      (setq P1	(polar IP 0 (/ T1 2))
	    P2	(polar P1 X (/ (- H (+ T2 T2 R1 R1)) 2))
	    P3	(polar P2 X R1)
	    P4	(polar P3 0 R1)
	    P5	(polar P4 0 (/ (- B (+ T1 R1 R1)) 2))
	    P6	(polar P5 X T2)
	    P7	(polar P6 Y B)
	    P8	(polar P7 Z T2)
	    P9	(polar P8 0 (/ (- B (+ T1 R1 R1)) 2))
	    P10	(polar P9 0 R1)
	    P11	(polar P10 Z R1)
	    P12	(polar P11 Z (- H (+ T2 T2 R1 R1)))
	    P13	(polar P12 Z R1)
	    P14	(polar P13 Y R1)
	    P15	(polar P14 Y (/ (- B (+ T1 R1 R1)) 2))
	    P16	(polar P15 Z T2)
	    P17	(polar P16 0 B)
	    P18	(polar P17 X T2)
	    P19	(polar P18 Y (/ (- B (+ T1 R1 R1)) 2))
	    P20	(polar P19 Y R1)
	    P21	(polar P20 X R1)
      )					;setq
      (command "_PLINE"	     P1	    "_W"	   "0.0"  "0.0"	 P2	"_ARC"
	       P4     "_LINE" P5	    P6	   P7	  P8	 P9	"_ARC"
	       P11    "LINE" P12    "_ARC"  P14	  "_LINE" P15	P16
	       P17    P18    P19    "_ARC"  P21	  "_LINE" P1	""
	      )				;command         
      (prompt "\nRotation Angle: ")
      (command "_ROTATE"
	       "_LAST"
	       ""
	       IP
	       pause
      );command
     (setvar "OSMODE" OLDSNAP)
    );while  
;;;*---------------------------------------------------------
    )					;progn
  )					;if
  (princ)
)					;defun UBEAM
;;;*=========================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS UNIVERSAL COLUMNS  
;;;*Written by K. Ramage September 1994.
;;;*Merged with DDSTEEL.LSP March 1997
;;;*--------------------------------------------------------
(defun UCOLUM (/     SIZA   size	 file  fp    item  data	 maxs  count
	       chrct numb  dlist X     Y     Z	   IP	 P1    P2
	       P3    P4	   P5	 P6    P7    P8	   P9	 P10   P11
	       P12   P13   P14	 P15   P16   P17   P18	 P19   P20
	       P21   NAMES
	      )
;;;*---------------------------------------------------------
;;;*CONVERT TO RADIANS
  (setq	X (* pi (/ 90.0 180.0))
	Y pi
	Z (* pi (/ 270.0 180.0))
  )					;setq
;;;*----------------------------------------------------------
;;;*INITIALISE
  (setvar "CMDECHO" 0)
  (setvar "BLIPMODE" 0)
  (setq	NAMES '("152x152x23"	   "152x152x30"
		"152x152x37"	   "203x203x46"
		"203x203x52"	   "203x203x60"
		"203x203x72"	   "203x203x86"
		"254x254x73"	   "254x254x89"
		"254x254x107"	   "254x254x132"
		"254x254x167"	   "305x305x97"
		"305x305x118"	   "305x305x137"
		"305x305x158"	   "305x305x198"
		"305x305x240"	   "305x305x283"
	       )
  )
  (setq dcl_id (load_dialog "ddsteel.dcl"))
  (if (not (new_dialog "ucolum" dcl_id))
    (exit)
  )
  (start_list "selections")
  (mapcar 'add_list NAMES)
  (end_list)
  (action_tile
    "cancel"
    "(done_dialog) (setq userclick1 nil)"
  )
  (action_tile
    "accept"
    (strcat
      "(progn (setq SIZA (atof (get_tile \"selections\")))"
      " (done_dialog)(setq userclick1 T))"
    )
  )
  (start_dialog)
  (unload_dialog dcl_id)
  (if userclick1
    (progn
      (setq SIZA (fix SIZA))
      (setq SIZA (nth SIZA NAMES))
      (grab)
;;;*THIS ROUTINE DRAWS A UNIVERSAL COLUMN.
      (mapcar 'set '(H B T1 T2 R1) dlist)
      (setvar "OSMODE" OLDSNAP)
      (while
      (setq IP (getpoint "\nInsertion Point: "))
      (setvar "OSMODE" 0)
      (setq P1	(polar IP 0 (/ T1 2))
	    P2	(polar P1 X (/ (- H (+ T2 T2 R1 R1)) 2))
	    P3	(polar P2 X R1)
	    P4	(polar P3 0 R1)
	    P5	(polar P4 0 (/ (- B (+ T1 R1 R1)) 2))
	    P6	(polar P5 X T2)
	    P7	(polar P6 Y B)
	    P8	(polar P7 Z T2)
	    P9	(polar P8 0 (/ (- B (+ T1 R1 R1)) 2))
	    P10	(polar P9 0 R1)
	    P11	(polar P10 Z R1)
	    P12	(polar P11 Z (- H (+ T2 T2 R1 R1)))
	    P13	(polar P12 Z R1)
	    P14	(polar P13 Y R1)
	    P15	(polar P14 Y (/ (- B (+ T1 R1 R1)) 2))
	    P16	(polar P15 Z T2)
	    P17	(polar P16 0 B)
	    P18	(polar P17 X T2)
	    P19	(polar P18 Y (/ (- B (+ T1 R1 R1)) 2))
	    P20	(polar P19 Y R1)
	    P21	(polar P20 X R1)
      )					;setq
      (command "_PLINE"	     P1	    "_W"	   "0.0"  "0.0"	 P2	"_ARC"
	       P4     "_LINE" P5	    P6	   P7	  P8	 P9	"_ARC"
	       P11    "_LINE" P12    "_ARC"  P14	  "_LINE" P15	P16
	       P17    P18    P19    "_ARC"  P21	  "_LINE" P1	""
	      )				;command         
      (prompt "\nRotation Angle: ")
      (command "_ROTATE"
	       "_LAST"
	       ""
	       IP
	       pause
      )					;command
      (setvar "OSMODE" OLDSNAP)
      );while
;;;*---------------------------------------------------------
    )					;progn
  )					;if
  (princ)
)					;defun UCOLUM
;;;*==========================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS TAPERED  
;;;*FLANGE CHANNELS.
;;;*Written by K. Ramage September 1994.
;;;*Merged with DDSTEEL.LSP March 1997
;;;*--------------------------------------------------------
(defun CHAN (/	  SIZA  size file fp   item data	maxs count     chrct
	     numb dlist	    X	 Y    Z	   IP	P1   P2	  P3   P4
	     P5	  P6   P7   P8	 P9   P10  P11	P15  P16  P17  H1
	     H2	  H3   H4   H5	 B1   B2   B3	B4   NAMES
	    )
;;;*---------------------------------------------------------
;;;*CONVERT TO RADIANS
  (setq	X (* pi (/ 90.0 180.0))
	Y pi
	Z (* pi (/ 270.0 180.0))
  )					;setq
;;;*----------------------------------------------------------
;;;*INITIALISE
  (setvar "CMDECHO" 0)
  (setvar "BLIPMODE" 0)
  (setq	NAMES '("100x50x11"	 "120x55x13"	  "140x60x16"
		"160x65x19"	 "180x70x22"	  "200x75x25"
		"220x80x29"	 "240x85x32"	  "260x90x38"
		"300x100x46"	 "76x38x7"	  "127x64x15"
		"152x76x18"	 "178x54x15"	  "381x102x55"
	       )
  )
  (setq dcl_id (load_dialog "ddsteel.dcl"))
  (if (not (new_dialog "chan" dcl_id))
    (exit)
  )
  (start_list "selections")
  (mapcar 'add_list NAMES)
  (end_list)
  (action_tile
    "cancel"
    "(done_dialog) (setq userclick1 nil)"
  )
  (action_tile
    "accept"
    (strcat
      "(progn (setq SIZA (atof (get_tile \"selections\")))"
      " (done_dialog)(setq userclick1 T))"
    )
  )
  (start_dialog)
  (unload_dialog dcl_id)
  (if userclick1
    (progn
      (setq SIZA (fix SIZA))
      (setq SIZA (nth SIZA NAMES))
      (grab)
;;;*THIS ROUTINE DRAWS A TAPERED FLANGE CHANNEL.
;;;*
      (mapcar 'set '(H B H1 H2 H3 H4 H5 B1 B2 B3 B4) dlist)
      (setvar "OSMODE" OLDSNAP)
      (while
     (setq IP (getpoint "\nInsertion Point: "))
      (setvar "OSMODE" 0)
      (setq P1	(polar IP Z H)
	    P2	(polar P1 0 B)
	    P3	(polar P2 X H1)
	    P4	(polar P3 X H2)
	    P5	(polar P4 Y B4)
	    P6	(polar P5 Y B3)
	    P7	(polar P6 X H3)
	    P8	(polar P7 Y B2)
	    P9	(polar P8 X H4)
	    P10	(polar P9 X H5)
	    P11	(polar P10 X H4)
	    P12	(polar P11 0 B2)
	    P13	(polar P12 X H3)
	    P14	(polar P13 0 B3)
	    P15	(polar P14 0 B4)
	    P16	(polar P15 X H2)
	    P17	(polar P16 X H1)
      )					;setq
      (command "_PLINE"	     IP	    "_W"	   "0.0"  "0.0"	 P1	P2
	       P3     "_ARC"  P5	    "_LINE" P7	  "_ARC"	 P9	"_LINE"
	       P10    "_ARC"  P12    "_LINE" P14	  "_ARC"	 P16	"_LINE"
	       P17    "_Close"
	      )				;command         
      (prompt "\nRotation Angle: ")
      (command "_ROTATE"
	       "_LAST"
	       ""
	       IP
	       pause
      )					;command
      (setvar "OSMODE" OLDSNAP)
      );while
;;;*---------------------------------------------------------
    )					;progn
  )					;if
  (princ)
)					;defun CHAN
;;;*===============================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS A CIRCULAR HOLLOW SECTION.  
;;;*Written by K. Ramage September 1994.
;;;*Merged with DDSTEEL.LSP March 1997
;;;*----------------------------------------------------------
(defun CHOLL (/ D D1 IP)
  (setvar "CMDECHO" 0)
  (setvar "OSMODE" OLDSNAP)
  (initget 1)
  (setq	IP (getpoint "\nInsertion Point: ")
	D  (getreal "\nOutside Diameter: ")
	D1 (getreal "\nInside Diameter: ")
	D  (/ D 2)
	D1 (/ D1 2)
  )					;setq
  (setvar "OSMODE" 0)
  (command "_CIRCLE"
	   IP
	   D
	   "_CIRCLE"
	   IP
	   D1
  )					;command
  (princ)
)
;;*defun CHOLL
;;;*=================================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS RSA's  
;;;*Written by K. Ramage September 1994.
;;;*Merged with DDSTEEL.LSP March 1997
;;;*--------------------------------------------------------
(defun RSA (/	  SIZA	fp    size  file  item	data  maxs  count chrct
	    numb  dlist	A     C	    IP	  P1	P2    P3    P4	  P5
	    P6	  P7	P8    P9    P10	  P11	NAMES
	   )
;;;*---------------------------------------------------------
;;;*CONVERT TO RADIANS
  (setq	A (* pi (/ 90.0 180.0))
	C pi
  )					;setq
;;;*----------------------------------------------------------
;;;*INITIALISE
  (setvar "CMDECHO" 0)
  (setvar "BLIPMODE" 0)
  (setq	NAMES '("25x25x3"	"25x25x5"	"30x30x3"
		"30x30x5"	"40x40x3"	"40x40x5"
		"40x40x6"	"45x45x3"	"45x45x5"
		"45x45x6"	"50x50x5"	"50x50x6"
		"50x50x8"	"60x60x5"	"60x60x6"
		"60x60x8"	"60x60x10"	"70x70x6"
		"70x70x8"	"70x70x10"	"80x80x6"
		"80x80x8"	"80x80x10"	"80x80x12"
		"90x90x8"	"90x90x10"	"90x90x12"
		"100x100x8"	"100x100x10"	"100x100x12"
		"100x100x15"	"120x120x10"	"120x120x12"
		"120x120x15"	"150x150x12"	"150x150x15"
		"150x150x18"	"200x200x16"	"200x200x18"
		"200x200x20"	"200x200x24"
	       )
  )
  (setq dcl_id (load_dialog "ddsteel.dcl"))
  (if (not (new_dialog "rsa" dcl_id))
    (exit)
  )
  (start_list "selections")
  (mapcar 'add_list NAMES)
  (end_list)
  (action_tile
    "cancel"
    "(done_dialog) (setq userclick1 nil)"
  )
  (action_tile
    "accept"
    (strcat
      "(progn (setq SIZA (atof (get_tile \"selections\")))"
      " (done_dialog)(setq userclick1 T))"
    )
  )
  (start_dialog)
  (unload_dialog dcl_id)
  (if userclick1
    (progn
      (setq SIZA (fix SIZA))
      (setq SIZA (nth SIZA NAMES))
      (grab)
;;;*THIS ROUTINE DRAWS A ROLLED STEEL ANGLE.
      (mapcar 'set '(H B T1 R1 R2) dlist)
      (setvar "OSMODE" OLDSNAP)
      (while
      (setq IP (getpoint "\nInsertion Point: "))
      (setvar "OSMODE" 0)
      (setq P1	(polar IP 0 B)
	    P2	(polar P1 A (- T1 R2))
	    P3	(polar P2 A R2)
	    P4	(polar P3 C R2)
	    P5	(polar P4 C (- B (+ T1 R1 R2)))
	    P6	(polar P5 C R1)
	    P7	(polar P6 A R1)
	    P8	(polar P7 A (- H (+ T1 R1 R2)))
	    P9	(polar P8 A R2)
	    P10	(polar P9 C R2)
	    P11	(polar P10 C (- T1 R2))
      )					;setq
      (command "_PLINE"	     IP	    "_W"	   "0.0"  ""	 P1	P2
	       "_ARC"  P4     "_LINE" P5	   "_ARC"  P7	 "_LINE"	P8
	       "_ARC"  P10    "_LINE" P11	   "_Close"
	      )				;command         
      (prompt "\nRotation Angle: ")
      (command "_ROTATE"
	       "_LAST"
	       ""
	       IP
	       pause
      )					;command
      (setvar "OSMODE" OLDSNAP)
      );while
;;;*---------------------------------------------------------
    )					;progn
  )					;if
  (princ)
)					;defun RSA
;;;*=========================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS UNEQUAL RSA's  
;;;*Written by K. Ramage September 1994.
;;;*Merged with DDSTEEL.LSP March 1997
;;;*--------------------------------------------------------
(defun URSA (/	   SIZA	 size  file  fp	   item	 data  maxs  count
	     chrct numb	 dlist A     C	   IP	 P1    P2    P3
	     P4	   P5	 P6    P7    P8	   P9	 P10   P11   NAMES
	    )
;;;*---------------------------------------------------------
;;;*CONVERT TO RADIANS
  (setq	A (* pi (/ 90.0 180.0))
	C pi
  )					;setq
;;;*----------------------------------------------------------
;;;*INITIALISE
  (setvar "CMDECHO" 0)
  (setvar "BLIPMODE" 0)
  (setq	NAMES '("65x50x6"	"65x50x8"	"75x50x6"
		"75x50x8"	"80x60x6"	"80x60x8"
		"90x65x6"	"90x65x8"	"90x65x10"
		"100x65x8"	"100x65x10"	"100x75x6"
		"100x75x8"	"100x75x10"	"100x75x12"
		"125x75x8"	"125x75x10"	"125x75x12"
		"150x75x10"	"150x75x12"	"150x75x15"
		"150x90x10"	"150x90x12"	"150x90x15"
	       )
  )
  (setq dcl_id (load_dialog "ddsteel.dcl"))
  (if (not (new_dialog "ursa" dcl_id))
    (exit)
  )
  (start_list "selections")
  (mapcar 'add_list NAMES)
  (end_list)
  (action_tile
    "cancel"
    "(done_dialog) (setq userclick1 nil)"
  )
  (action_tile
    "accept"
    (strcat
      "(progn (setq SIZA (atof (get_tile \"selections\")))"
      " (done_dialog)(setq userclick1 T))"
    )
  )
  (start_dialog)
  (unload_dialog dcl_id)
  (if userclick1
    (progn
      (setq SIZA (fix SIZA))
      (setq SIZA (nth SIZA NAMES))
      (grab)
;;;*THIS ROUTINE DRAWS A ROLLED STEEL ANGLE.
      (mapcar 'set '(H B T1 R1 R2) dlist)
      (setvar "OSMODE" OLDSNAP)
      (while
      (setq IP (getpoint "\nInsertion Point: "))
      (setvar "OSMODE" 0)
      (setq P1	(polar IP 0 B)
	    P2	(polar P1 A (- T1 R2))
	    P3	(polar P2 A R2)
	    P4	(polar P3 C R2)
	    P5	(polar P4 C (- B (+ T1 R1 R2)))
	    P6	(polar P5 C R1)
	    P7	(polar P6 A R1)
	    P8	(polar P7 A (- H (+ T1 R1 R2)))
	    P9	(polar P8 A R2)
	    P10	(polar P9 C R2)
	    P11	(polar P10 C (- T1 R2))
      )					;setq
      (command "_PLINE"	     IP	    "_W"	   "0.0"  ""	 P1	P2
	       "_ARC"  P4     "_LINE" P5	   "_ARC"  P7	 "_LINE"	P8
	       "_ARC"  P10    "_LINE" P11	   "_Close"
	      )				;command         
      (prompt "\nRotation Angle: ")
      (command "_ROTATE"
	       "_LAST"
	       ""
	       IP
	       pause
      )					;command
      (setvar "OSMODE" OLDSNAP)
      );while
;;;*---------------------------------------------------------
    )					;progn
  )					;if
  (princ)
)					;defun URSA
;;;*==========================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS A SQUARE OR RECTANGULAR
;;;*HOLLOW SECTION ACCORDING TO THE VALUES INPUT BY USER.
;;;*Written by Kenny Ramage September 1994
;;;*Merged with DDSTEEL.LSP March 1997
(defun SHOLL (/	x y z h	b t1 r1	r2 h1 b1 p1 p2 p3 p4 p5	p6 p7 p8 p9 p10
	      p11 p12 p13)
  (setvar "CMDECHO" 0)
  (setvar "BLIPMODE" 0)
  (setvar "OSMODE" OLDSNAP)
  ;;*--------------------------------------------------------
  (setq	x (* pi (/ 90.0 180.0))
	y pi
	z (* pi (/ 270.0 180.0))
  )					;setq
;;;*-------------------------------------------------------
  (initget 1)
  (setq ip (getpoint "\nInsertion Point <Pick Point>: "))
  (initget 7)
  (setq h (getreal "\nHeight of Section <mm>: "))
  (initget 7)
  (setq b (getreal "\nWidth of Section <mm>: "))
  (initget 7)
  (setq t1 (getreal "\nWall Thickness <mm>: "))
  (setq	r2 (/ t1 2)
	h1 (- h t1 t1)
	b1 (- b t1 t1)
	r1 (+ t1 r2)
  )					;setq
;;;*-------------------------------------------------------
  (setvar "OSMODE" 0)
  (repeat 2
    (setq p1  (polar ip 0 (/ b 2))
	  p2  (polar p1 x (/ (- h r1 r1) 2))
	  p3  (polar p2 x r1)
	  p4  (polar p3 y r1)
	  p5  (polar p4 y (- b r1 r1))
	  p6  (polar p5 y r1)
	  p7  (polar p6 z r1)
	  p8  (polar p7 z (- h r1 r1))
	  p9  (polar p8 z r1)
	  p10 (polar p9 0 r1)
	  p11 (polar p10 0 (- b r1 r1))
	  p12 (polar p11 0 r1)
	  p13 (polar p12 x r1)
    )					;setq
;;;*--------------------------------------------------------
    (command "_Pline"	   p1	  "_W"	 "0.0"	"0.0"  p2     "_Arc"
	     p4	    "_Line" p5	  "_Arc"	 p7	"_Line" p8     "_Arc"
	     p10    "_Line" p11	  "_Arc"	 p13	"_Line" p1     ""
	    )				;command
;;;*---------------------------------------------------------            
    (setq h  h1
	  b  b1
	  r1 r2
    )					;setq
;;;*---------------------------------------------------------
  )					;repeat
;;;*----------------------------------------------------------
  (princ)
)					;defun
;;;*END SHOLL
;;;*==========================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS JOISTS  
;;;*Written by K. Ramage September 1994.
;;;*Merged with DDSTEEL.LSP March 1997
;;;*--------------------------------------------------------
(defun JOIST (/	   SIZA	size file fp   item data maxs count	chrct
	      numb dlist     X	  Y    Z    IP	 P1   P2   P3	P4
	      P5   P6	P7   P8	  P9   P10  P11	 P15  P16  P17	P18
	      P19  P20	P21  P22  P23  P24  P25	 P26  P27  P28	P29
	      P30  P31	P32  P33  H1   H2   H3	 H4   H5   B1	B2
	      B3   B4
	     )
;;;*---------------------------------------------------------
;;;*CONVERT TO RADIANS
  (setq	X (* pi (/ 90.0 180.0))
	Y pi
	Z (* pi (/ 270.0 180.0))
  )					;setq
;;;*----------------------------------------------------------
;;;*INITIALISE
  (setvar "CMDECHO" 0)
  (setvar "BLIPMODE" 0)
  (setq	NAMES '("127x76x13"	  "152x89x17"	    "178x102x22"
		"203x102x25"	  "203x152x52"	    "254x152x59"
		"305x152x66"
	       )
  )
  (setq dcl_id (load_dialog "ddsteel.dcl"))
  (if (not (new_dialog "joist" dcl_id))
    (exit)
  )
  (start_list "selections")
  (mapcar 'add_list NAMES)
  (end_list)
  (action_tile
    "cancel"
    "(done_dialog) (setq userclick1 nil)"
  )
  (action_tile
    "accept"
    (strcat
      "(progn (setq SIZA (atof (get_tile \"selections\")))"
      " (done_dialog)(setq userclick1 T))"
    )
  )
  (start_dialog)
  (unload_dialog dcl_id)
  (if userclick1
    (progn
      (setq SIZA (fix SIZA))
      (setq SIZA (nth SIZA NAMES))
      (grab)
;;;*THIS ROUTINE DRAWS A JOIST.
      (mapcar 'set '(H B H1 H2 H3 H4 H5 B1 B2 B3 B4) dlist)
      (setvar "OSMODE" OLDSNAP)
      (while
      (setq IP (getpoint "\nInsertion Point: "))
      (setvar "OSMODE" 0)
      (setq P1	(polar IP 0 B1)
	    P2	(polar P1 X (/ H5 2))
	    P3	(polar P2 X H4)
	    P4	(polar P3 0 B2)
	    P5	(polar P4 X H3)
	    P6	(polar P5 0 B3)
	    P7	(polar P6 0 B4)
	    P8	(polar P7 X H2)
	    P9	(polar P8 X H1)
	    P10	(polar P9 Y B)
	    P11	(polar P10 Z H1)
	    P12	(polar P11 Z H2)
	    P13	(polar P12 0 B4)
	    P14	(polar P13 0 B3)
	    P15	(polar P14 Z H3)
	    P16	(polar P15 0 B2)
	    P17	(polar P16 Z H4)
	    P18	(polar P17 Z H5)
	    P19	(polar P18 Z H4)
	    P20	(polar P19 Y B2)
	    P21	(polar P20 Z H3)
	    P22	(polar P21 Y B3)
	    P23	(polar P22 Y B4)
	    P24	(polar P23 Z H2)
	    P25	(polar P24 Z H1)
	    P26	(polar P25 0 B)
	    P27	(polar P26 X H1)
	    P28	(polar P27 X H2)
	    P29	(polar P28 Y B4)
	    P30	(polar P29 Y B3)
	    P31	(polar P30 X H3)
	    P32	(polar P31 Y B2)
	    P33	(polar P32 X H4)
      )					;setq
      (command "_PLINE"	     P1	    "_W"	   "0.0"  "0.0"	 P2	"_ARC"
	       P4     "_LINE" P6	    "_ARC"  P8	  "_LINE" P9	P10
	       P11    "_ARC"  P13    "_LINE" P15	  "_ARC"	 P17	"_LINE"
	       P18    "_ARC"  P20    "_LINE" P22	  "_ARC"	 P24	"_LINE"
	       P25    P26    P27    "_ARC"  P29	  "_LINE" P31	"_ARC"
	       P33    "_LINE" P1	    ""
	      )				;command         
      (prompt "\nRotation Angle: ")
      (command "_ROTATE"
	       "_LAST"
	       ""
	       IP
	       pause
      )					;command
      (setvar "OSMODE" OLDSNAP)
      );while
;;;*---------------------------------------------------------
    )					;progn
  )					;if
  (princ)
)					;defun JOIST
;;;*==========================================================
;;;*THIS PARAMETRIC ROUTINE DRAWS PARALLEL  
;;;*FLANGE CHANNELS.
;;;*Written by K. Ramage September 1994.
;;;*Merged with DDSTEEL.LSP March 1997
;;;*--------------------------------------------------------
(defun PCHAN (/	    SIZA	  size	file  fp    item  data	maxs  count
	      chrct numb  dlist	X     Y	    Z	  IP	P1    P2
	      P3    P4	  P5	P6    P7    P8	  P9	P10   P11
	      NAMES
	     )
;;;*---------------------------------------------------------
;;;*CONVERT TO RADIANS
  (setq	X (* pi (/ 90.0 180.0))
	Y pi
	Z (* pi (/ 270.0 180.0))
  )					;setq
;;;*----------------------------------------------------------
;;;*INITIALISE
  (setvar "CMDECHO" 0)
  (setvar "BLIPMODE" 0)
  (setq	NAMES '("100x50x10"	 "120x55x13"	  "140x60x15"
		"160x65x18"	 "180x70x21"	  "200x75x24"
		"220x80x28"	 "240x85x32"	  "260x90x36"
		"280x95x41"	 "300x100x45"
	       )
  )
  (setq dcl_id (load_dialog "ddsteel.dcl"))
  (if (not (new_dialog "pchan" dcl_id))
    (exit)
  )
  (start_list "selections")
  (mapcar 'add_list NAMES)
  (end_list)
  (action_tile
    "cancel"
    "(done_dialog) (setq userclick1 nil)"
  )
  (action_tile
    "accept"
    (strcat
      "(progn (setq SIZA (atof (get_tile \"selections\")))"
      " (done_dialog)(setq userclick1 T))"
    )
  )
  (start_dialog)
  (unload_dialog dcl_id)
  (if userclick1
    (progn
      (setq SIZA (fix SIZA))
      (setq SIZA (nth SIZA NAMES))
      (grab)
;;;*THIS ROUTINE DRAWS A PARALLEL FLANGE CHANNEL.
      (mapcar 'set '(H B T1 T2 R1) dlist)
      (setvar "OSMODE" OLDSNAP)
      (while
      (setq IP (getpoint "\nInsertion Point: "))
      (setvar "OSMODE" 0)
      (setq P1	(polar IP Z H)
	    P2	(polar P1 0 B)
	    P3	(polar P2 X T2)
	    P4	(polar P3 Y (- B (+ R1 T1)))
	    P5	(polar P4 Y R1)
	    P6	(polar P5 X R1)
	    P7	(polar P6 X (- H (+ T2 T2 R1 R1)))
	    P8	(polar P7 X R1)
	    P9	(polar P8 0 R1)
	    P10	(polar P9 0 (- B (+ R1 T1)))
	    P11	(polar P10 X T2)
      )					;setq
      (command "_PLINE"	     IP	    "_W"	   "0.0"  "0.0"	 P1	P2
	       P3     P4     "_ARC"  P6	   "_LINE" P7	 "_ARC"	P9
	       "_LINE" P10    P11    "_Close"
	      )				;command         
      (prompt "\nRotation Angle: ")
      (command "_ROTATE"
	       "_LAST"
	       ""
	       IP
	       pause
      )					;command
      (setvar "OSMODE" OLDSNAP)
      );while
;;;*---------------------------------------------------------
    )					;progn
  )					;if
  (princ)
)					;defun PCHAN
;;;*FILE & INFORMATION RETRIEVAL ROUTINE.
(defun grab ()
  (setq	dlist nil
	size  (strcat "*" SIZA)
	file  (findfile "DDSTEEL.DAT")
	fp    (open file "r")
	item  (read-line fp)
  )					;setq
  (while item
    (if	(= item size)
      (setq data (read-line fp)
	    item nil
      )					;setq
      (setq item (read-line fp))
    )					;if
  )					;while
  (if data
    (progn
      (setq maxs  (strlen data)
	    count 1
	    chrct 1
      )					;setq
      (while (< count maxs)
	(if (/= "," (substr data count 1))
	  (setq chrct (1+ chrct))
	  (setq	numb  (atof (substr data (1+ (- count chrct)) chrct))
		dlist (append dlist (list numb))
		chrct 1
	  )				;setq
	)				;if
	(setq count (1+ count))
      )					;while
      (setq numb  (atof (substr data (1+ (- count chrct))))
	    dlist (append dlist (list numb))
      )					;setq
    )					;progn
  )					;if data
  (close fp)
)					;defun
;;;*==========================================================
;;;*==========================================================
(defun initerr ()
  (setq oldlayer (getvar "clayer"))
  (setq oldsnap (getvar "osmode"))
  (setq oldpick (getvar "pickbox"))
  (setq temperr *error*)
  (setq *error* trap)
  (princ)
)					;defun
;;;*===========================================================
(defun trap (errmsg)
  (command nil nil nil)
  (if (not (member errmsg '("console break" "Function Cancelled"))
      )
    (princ (strcat "\nError: " errmsg))
  )					;                 
  (setvar "clayer" oldlayer)
  (setvar "blipmode" 1)
  (setvar "menuecho" 0)
  (setvar "highlight" 1)
  (setvar "osmode" oldsnap)
  (setvar "pickbox" oldpick)
  (princ "\nError Resetting Enviroment ")
  (terpri)
  (setq *error* temperr)
  (princ)
)					;defun
;;;*===========================================================
(defun reset ()
  (setq *error* temperr)
  (setvar "clayer" oldlayer)
  (setvar "blipmode" 1)
  (setvar "menuecho" 0)
  (setvar "highlight" 1)
  (setvar "osmode" oldsnap)
  (setvar "pickbox" oldpick)
  (princ)
)					;defun
;;;*======================================================
(princ)
					;* end of CATCH1.LSP

;;;*End File DDSTEEL.LSP

